==> open-xchange-documents-backend_7.10.1.orig.tar.bz2: open-xchange-documents-backend-7.10.1/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odf/table/Cell.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odf.table;

import org.apache.xml.serializer.SerializationHandler;
import org.odftoolkit.odfdom.IElementWriter;
import org.xml.sax.SAXException;
import com.openexchange.office.filter.odf.AttributeImpl;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.DLList;
import com.openexchange.office.filter.odf.INodeAccessor;
import com.openexchange.office.filter.odf.Namespaces;
import com.openexchange.office.filter.odf.SaxContextHandler;
import com.openexchange.office.filter.odt.dom.TextContentHelper;

public class Cell implements INodeAccessor, IElementWriter, Cloneable {

	private final AttributesImpl attributes;
	private int columnsSpanned = 1;
	private int rowsSpanned = 1;

	private DLList<Object> content = new DLList<Object>();

	public Cell() {
		this.attributes = new AttributesImpl();
		init();
	}

	public Cell(AttributesImpl attributesImpl) {
		this.attributes = attributesImpl;
		init();
	}

	private void init() {
	    AttributeImpl attribute = attributes.remove("table:number-columns-spanned");
	    if(attribute!=null) {
	        columnsSpanned = attribute.getIntValue(1);
	    }
	    attribute = attributes.remove("table:number-rows-spanned");
	    if(attribute!=null) {
	        rowsSpanned = attribute.getIntValue(1);
	    }
	}

	public int getColumnSpan() {
	    return columnsSpanned;
	}

	public void setColumnSpan(Integer n) {
	    columnsSpanned = n;
	}

	public int getRowSpan() {
	    return rowsSpanned;
	}

	public void setRowSpan(Integer n) {
	    rowsSpanned = n;
	}

	public String getStyleName() {
		return attributes.getValue("table:style-name");
	}

	public void setStyleName(String styleName) {
		attributes.setValue(Namespaces.TABLE, "style-name", "table:style-name", styleName);
	}

	@Override
	public DLList<Object> getContent() {
		return content;
	}

	@Override
    public void writeObject(SerializationHandler output)
		throws SAXException {

		SaxContextHandler.startElement(output, Namespaces.TABLE, "table-cell", "table:table-cell");
		attributes.write(output);
		if(columnsSpanned>1) {
		    SaxContextHandler.addAttribute(output, Namespaces.TABLE, "number-columns-spanned", "table:number-columns-spanned", columnsSpanned);
		}
		if(rowsSpanned>1) {
            SaxContextHandler.addAttribute(output, Namespaces.TABLE, "number-rows-spanned", "table:number-rows-spanned", rowsSpanned);
		}
		TextContentHelper.write(output, getContent());
		SaxContextHandler.endElement(output, Namespaces.TABLE, "table-cell", "table:table-cell");

		final int columnSpan = getColumnSpan();
		for(int i = 1; i < columnSpan; i++) {
			SaxContextHandler.startElement(output, Namespaces.TABLE, "covered-table-cell", "table:covered-table-cell");
			SaxContextHandler.endElement(output, Namespaces.TABLE, "covered-table-cell", "table:covered-table-cell");
		}
	}

	@Override
	public Cell clone() {
		final Cell clone = new Cell();
		final String cellStyle = getStyleName();
		if(cellStyle!=null) {
			clone.setStyleName(cellStyle);
		}
		final int columnSpan = getColumnSpan();
		if(columnSpan!=1) {
			clone.setColumnSpan(columnSpan);
		}
		final int rowSpan = getRowSpan();
		if(rowSpan!=1) {
			clone.setRowSpan(rowSpan);
		}
		return clone;
	}
}

==> open-xchange-documents-backend_7.10.2.orig.tar.bz2: open-xchange-documents-backend-7.10.2/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odf/table/Cell.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odf.table;

import org.apache.xml.serializer.SerializationHandler;
import org.odftoolkit.odfdom.IElementWriter;
import org.xml.sax.SAXException;
import com.openexchange.office.filter.core.DLList;
import com.openexchange.office.filter.core.INodeAccessor;
import com.openexchange.office.filter.odf.AttributeImpl;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.Namespaces;
import com.openexchange.office.filter.odf.SaxContextHandler;
import com.openexchange.office.filter.odt.dom.TextContentHelper;

public class Cell implements INodeAccessor, IElementWriter, Cloneable {

	private final AttributesImpl attributes;
	private int columnsSpanned = 1;
	private int rowsSpanned = 1;

	private DLList<Object> content = new DLList<Object>();

	public Cell() {
		this.attributes = new AttributesImpl();
		init();
	}

	public Cell(AttributesImpl attributesImpl) {
		this.attributes = attributesImpl;
		init();
	}

	private void init() {
	    AttributeImpl attribute = attributes.remove("table:number-columns-spanned");
	    if(attribute!=null) {
	        columnsSpanned = attribute.getIntValue(1);
	    }
	    attribute = attributes.remove("table:number-rows-spanned");
	    if(attribute!=null) {
	        rowsSpanned = attribute.getIntValue(1);
	    }
	}

	public int getColumnSpan() {
	    return columnsSpanned;
	}

	public void setColumnSpan(Integer n) {
	    columnsSpanned = n;
	}

	public int getRowSpan() {
	    return rowsSpanned;
	}

	public void setRowSpan(Integer n) {
	    rowsSpanned = n;
	}

	public String getStyleName() {
		return attributes.getValue("table:style-name");
	}

	public void setStyleName(String styleName) {
		attributes.setValue(Namespaces.TABLE, "style-name", "table:style-name", styleName);
	}

	@Override
	public DLList<Object> getContent() {
		return content;
	}

	@Override
    public void writeObject(SerializationHandler output)
		throws SAXException {

		SaxContextHandler.startElement(output, Namespaces.TABLE, "table-cell", "table:table-cell");
		attributes.write(output);
		if(columnsSpanned>1) {
		    SaxContextHandler.addAttribute(output, Namespaces.TABLE, "number-columns-spanned", "table:number-columns-spanned", columnsSpanned);
		}
		if(rowsSpanned>1) {
            SaxContextHandler.addAttribute(output, Namespaces.TABLE, "number-rows-spanned", "table:number-rows-spanned", rowsSpanned);
		}
		TextContentHelper.write(output, getContent());
		SaxContextHandler.endElement(output, Namespaces.TABLE, "table-cell", "table:table-cell");

		final int columnSpan = getColumnSpan();
		for(int i = 1; i < columnSpan; i++) {
			SaxContextHandler.startElement(output, Namespaces.TABLE, "covered-table-cell", "table:covered-table-cell");
			SaxContextHandler.endElement(output, Namespaces.TABLE, "covered-table-cell", "table:covered-table-cell");
		}
	}

	@Override
	public Cell clone() {
		final Cell clone = new Cell();
		final String cellStyle = getStyleName();
		if(cellStyle!=null) {
			clone.setStyleName(cellStyle);
		}
		final int columnSpan = getColumnSpan();
		if(columnSpan!=1) {
			clone.setColumnSpan(columnSpan);
		}
		final int rowSpan = getRowSpan();
		if(rowSpan!=1) {
			clone.setRowSpan(rowSpan);
		}
		return clone;
	}
}
